%define anolis_release 1

Name:           libglvnd
Version:        1.6.0
Release:        %{anolis_release}%{?dist}
# Provide an upgrade path from the negativo17.org pkgs which have Epoch 1
Epoch:          1
Summary:        The GL Vendor-Neutral Dispatch library

License:        MIT
URL:            https://gitlab.freedesktop.org/glvnd/libglvnd
Source0:        https://gitlab.freedesktop.org/glvnd/libglvnd/-/archive/v%{version}/%{name}-v%{version}.tar.bz2

BuildRequires:  meson >= 0.48.0
BuildRequires:  gcc
BuildRequires:  python3-rpm-macros
BuildRequires:  python3-libxml2
BuildRequires:  pkgconfig(glproto)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  xorg-x11-server-Xvfb

%{?_without_mesa_glvnd_default:
%global __provides_exclude_from %{_libdir}/%{name}
%global __requires_exclude_from %{_libdir}/%{name}
}

%description
libglvnd is an implementation of the vendor-neutral dispatch layer for
arbitrating OpenGL API calls between multiple vendors on a per-screen basis.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       %{name}-opengl = %{epoch}:%{version}-%{release}
Requires:       %{name}-gles = %{epoch}:%{version}-%{release}
Requires:       %{name}-glx = %{epoch}:%{version}-%{release}
Requires:       %{name}-egl = %{epoch}:%{version}-%{release}
Requires:       %{name}-core-devel = %{epoch}:%{version}-%{release}
# Required by any glx.h users.
Requires:       libX11-devel
# We might split into more sub-packages
Obsoletes:      mesa-libGLES-devel < 19.3.0
Provides:       mesa-libGLES-devel = %{epoch}:%{version}-%{release}
Obsoletes:      mesa-khr-devel < 19.3.0
Provides:       mesa-khr-devel = %{epoch}:%{version}-%{release}
Provides:       libGLES-devel = %{epoch}:%{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package        core-devel
Summary:        Core development files for %{name}

%description core-devel
The %{name}-core-devel package is a bootstrap trick for Mesa, which wants
to build against the %{name} headers but does not link against any of
its libraries (and, initially, has file conflicts with them). If you are
not Mesa you almost certainly want %{name}-devel instead.


%package        opengl
Summary:        OpenGL support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    opengl
libOpenGL is the common dispatch interface for the workstation OpenGL API.


%package        gles
Summary:        GLES support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}
%{!?_without_mesa_glvnd_default:
# mesa is the default EGL implementation provider
Requires:       mesa-libEGL >= 13.0.4
Obsoletes:      mesa-libGLES < 19.3.0
Provides:       mesa-libGLES
Provides:       libGLES
}

%description    gles
libGLESv[12] are the common dispatch interface for the GLES API.


%package        egl
Summary:        EGL support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}
%{!?_without_mesa_glvnd_default:
# mesa is the default EGL implementation provider
Requires:       mesa-libEGL >= 13.0.4
Provides:       libEGL
}

%description    egl
libEGL are the common dispatch interface for the EGL API.


%package        glx
Summary:        GLX support for libglvnd
Requires:       %{name} = %{epoch}:%{version}-%{release}
%{!?_without_mesa_glvnd_default:
# mesa is the default GL implementation provider
Requires:       mesa-libGL >= 13.0.4
Provides:       libGL
}

%description    glx
libGL and libGLX are the common dispatch interface for the GLX API.


%prep
%autosetup -p1 -n %{name}-v%{version}

%build
%meson -Dasm=enabled -Dtls=true
%meson_build

%install
%meson_install

%{?_without_mesa_glvnd_default:
# Avoid conflict with mesa-libGL
mkdir -p %{buildroot}%{_libdir}/%{name}/
for l in libEGL libGL libGLESv1_CM libGLESv2 libGLX; do
  mv %{buildroot}%{_libdir}/${l}.so* \
    %{buildroot}%{_libdir}/%{name}/
done
}

# Create directory layout
mkdir -p %{buildroot}%{_sysconfdir}/glvnd/egl_vendor.d/
mkdir -p %{buildroot}%{_datadir}/glvnd/egl_vendor.d/
mkdir -p %{buildroot}%{_sysconfdir}/egl/egl_external_platform.d/
mkdir -p %{buildroot}%{_datadir}/egl/egl_external_platform.d/

%generate_compatibility_deps

%check
%ifarch x86_64
xvfb-run -s '-screen 0 640x480x24' -d \
  %{__meson} test -C %{_vpath_builddir} --num-processes %{_smp_build_ncpus}
%endif

%files
%dir %{abidir}
%dir %{_sysconfdir}/glvnd/
%dir %{_datadir}/glvnd/
%{_libdir}/libGLdispatch.so.0*
%{abidir}/libGLdispatch.dump

%files doc
%doc README.md

%files opengl
%{_libdir}/libOpenGL.so.0*
%{abidir}/libOpenGL.dump

%files gles
%if 0%{?_without_mesa_glvnd_default}
%{_libdir}/%{name}/libGLES*.so.*
%{abidir}/libGLES*.dump
%else
%{_libdir}/libGLES*.so.*
%{abidir}/libGLES*.dump
%endif

%files glx
%if 0%{?_without_mesa_glvnd_default}
%{_libdir}/%{name}/libGL.so.*
%{_libdir}/%{name}/libGLX.so.*
%{abidir}/libGL.dump
%{abidir}/libGLX.dump
%else
%{_libdir}/libGL.so.*
%{_libdir}/libGLX.so.*
%{abidir}/libGL.dump
%{abidir}/libGLX.dump
%endif

%files egl
%dir %{_sysconfdir}/glvnd/egl_vendor.d/
%dir %{_datadir}/glvnd/egl_vendor.d/
%dir %{_sysconfdir}/egl/
%dir %{_sysconfdir}/egl/egl_external_platform.d/
%dir %{_datadir}/egl/
%dir %{_datadir}/egl/egl_external_platform.d/
%if 0%{?_without_mesa_glvnd_default}
%{_libdir}/%{name}/libEGL*.so.*
%{abidir}/libEGL*.dump
%else
%{_libdir}/libEGL*.so.*
%{abidir}/libEGL*.dump
%endif

%files core-devel
%dir %{_includedir}/glvnd/
%{_includedir}/glvnd/*.h
%{_libdir}/pkgconfig/libglvnd.pc

%files devel
%dir %{_includedir}/EGL/
%dir %{_includedir}/GL/
%dir %{_includedir}/GLES/
%dir %{_includedir}/GLES2/
%dir %{_includedir}/GLES3/
%dir %{_includedir}/KHR/
%{_includedir}/EGL/*.h
%{_includedir}/GL/*.h
%{_includedir}/GLES/*.h
%{_includedir}/GLES2/*.h
%{_includedir}/GLES3/*.h
%{_includedir}/KHR/*.h
%{_libdir}/lib*.so
%if 0%{?_without_mesa_glvnd_default}
%{_libdir}/%{name}/lib*.so
%endif
%{_libdir}/pkgconfig/gl*.pc
%{_libdir}/pkgconfig/egl.pc
%{_libdir}/pkgconfig/opengl.pc


%changelog
* Sun Jan 8 2023 Funda Wang <fundawang@yeah.net> - 1:1.6.0-1
- New version 1.6.0
- Use meson for faster build

* Tue Oct 25 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.5.0-2
- optimise spec file

* Mon Sep 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.5.0-1
- update to 1.5.0

* Thu Apr 21 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1:1.4.0-1
- Init from upstream version 1.4.0

